@@ -9,7 +9,6 @@ from typing import Any, Iterable
 from aiochannel import Channel
 from aiomisc import threaded_iterable_separate
 from aiomisc.service.periodic import PeriodicService
-from prometheus_client import Counter, Summary
 
 from cgroups_exporter.metrics import (
     HANDLER_REGISTRY, CGroupTask, metrics_handler,
@@ -30,34 +29,20 @@ class Collector(PeriodicService):
 
     SPLIT_EXP = re.compile(
         r"^(?P<base>.*)/(?P<group>{0})/(?P<path>.*)/?$".format("|".join(groups)),
-    )
-
-    RUN_COUNTER = Counter(
-        "calls",
-        documentation="Exporter collector run counter",
-        namespace="cgroups",
-        subsystem="exporter",
-        unit="collector",
-    )
-
-    COLLECT_TIME = Summary(
-        "collect_time",
-        documentation="Exporter collector execution time",
-        namespace="cgroups",
-        subsystem="exporter",
-        unit="collector",
+                
     )
 
     @threaded_iterable_separate(max_size=1024)
     def resolve_paths(self):
         for path_glob in self.cgroup_paths:
             for path in glob.glob(path_glob, recursive=True):
-                log.debug("Processing path %s", path)
 
                 if not os.path.isdir(path):
-                    log.debug("Is not directory path %r skipping...", path)
+                    #log.debug("Is not directory path %r skipping...", path)
                     continue
 
+                log.debug("Processing path %s", path)
+
                 match = self.SPLIT_EXP.match(path)
 
                 if match is None:
@@ -87,17 +72,15 @@ class Collector(PeriodicService):
     async def callback(self) -> Any:
         log.debug("Starting to collect metrics")
 
-        with self.COLLECT_TIME.time():
-            channel = Channel(maxsize=self.max_workers * 2)
-            tasks = [self.producer(channel)]
+        channel = Channel(maxsize=self.max_workers * 2)
+        tasks = [self.producer(channel)]
 
-            for _ in range(self.max_workers):
-                tasks.append(self.worker(channel))
+        for _ in range(self.max_workers):
+            tasks.append(self.worker(channel))
 
-            await self.before_collect()
-            await asyncio.gather(*tasks)
-
-        self.RUN_COUNTER.inc()
+        await self.before_collect()
+        await asyncio.gather(*tasks)
 
     async def before_collect(self):
         await uptade_device_ids()
+
